Host
=============

.. automodule:: wexpect.host

Functions
---------

.. automethod:: wexpect.host.run

SpawnPipe
---------

.. autoclass:: SpawnPipe

  .. automethod:: __init__
  .. automethod:: expect
  .. automethod:: expect_exact
  .. automethod:: expect_list
  .. automethod:: compile_pattern_list
  .. automethod:: send
  .. automethod:: sendline
  .. automethod:: write
  .. automethod:: writelines
  .. automethod:: sendeof
  .. automethod:: read
  .. automethod:: readline
  .. automethod:: read_nonblocking


SpawnSocket
-----------

.. autoclass:: SpawnSocket

  .. automethod::  __init__
  .. automethod:: expect
  .. automethod:: expect_exact
  .. automethod:: expect_list
  .. automethod:: compile_pattern_list
  .. automethod:: send
  .. automethod:: sendline
  .. automethod:: write
  .. automethod:: writelines
  .. automethod:: sendeof
  .. automethod:: read
  .. automethod:: readline
  .. automethod:: read_nonblocking
